Module resilience

Module resilience 

Classify agent tick failures so the loop can backoff instead of exiting.

Enums

AgentErrorClass
How the agent should react to a tick (or startup) error.

Functions

backoff_seconds
Exponential backoff from consecutive failure count (1-based).
class_label
classify_agent_error
Classify an error from its Display / Debug chain text.
classify_error_message