pub enum AgentCommands {
Schema,
Validate {
file: PathBuf,
},
Status {
rules_file: Option<PathBuf>,
},
Run {
file: PathBuf,
once: bool,
background: bool,
},
Stop {
file: PathBuf,
},
CloseAll {
file: PathBuf,
},
Sim {
command: AgentSimCommands,
},
Backtest {
command: AgentBacktestCommands,
},
}Variants
Schema
JSON Schema for rules.yaml
Validate
Validate rules.yaml structure
Status
Show persisted agent state
Run
Run the options agent loop (requires –trust –yes for live trades)
Fields
Stop
Stop a background agent started with agent run --background
CloseAll
Close all spreads tracked in agent state for this rules file (NOT whole account)
Sim
Paper-trading stats and ledger for –simulate runs
Fields

command: AgentSimCommandsBacktest
Historical options backtest (synthetic BS marks over Schwab daily bars)
Fields

command: AgentBacktestCommandsTrait Implementations
Sourceimpl Debug for AgentCommands
impl Debug for AgentCommands
Sourceimpl FromArgMatches for AgentCommands
impl FromArgMatches for AgentCommands
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut<'b>(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut<'b>( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourceimpl Subcommand for AgentCommands
impl Subcommand for AgentCommands
Sourcefn augment_subcommands<'b>(__clap_app: Command) -> Command
fn augment_subcommands<'b>(__clap_app: Command) -> Command
Sourcefn augment_subcommands_for_update<'b>(__clap_app: Command) -> Command
fn augment_subcommands_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourcefn has_subcommand(__clap_name: &str) -> bool
fn has_subcommand(__clap_name: &str) -> bool
Test whether
Self can parse a specific subcommandAuto Trait Implementations
impl Freeze for AgentCommands
impl RefUnwindSafe for AgentCommands
impl Send for AgentCommands
impl Sync for AgentCommands
impl Unpin for AgentCommands
impl UnsafeUnpin for AgentCommands
impl UnwindSafe for AgentCommands