Classify agent tick failures so the loop can backoff instead of exiting.
Enums
- Agent
Error Class - How the agent should react to a tick (or startup) error.
Functions
- backoff_
seconds - Exponential backoff from consecutive failure count (1-based).
- class_
label - classify_
agent_ error - Classify an error from its Display / Debug chain text.
- classify_
error_ message